<?php

namespace Drupal\stackla_widget\Api;

/**
 * Interfave for Stackla API.
 */
interface RequestInterface {

  /**
   * Host setter.
   *
   * @param string $host
   *   API host name.
   */
  public function setHost(string $host = '');

  /**
   * API key setter.
   *
   * @param string $apiKey
   *   Client API key.
   */
  public function setApiKey(string $apiKey = '');

  /**
   * Stack setter.
   *
   * @param string $stack
   *   Client stack name.
   */
  public function setStack(string $stack = '');

  /**
   * This method will do GET request to Stackla API.
   *
   * @param string $endpoint
   *   The operation / task for API.
   * @param array $data
   *   The parameter need to be passed.
   *
   * @return \GuzzleHttp\Message\Response
   *   This will return FALSE or json object.
   */
  public function sendGet(string $endpoint = '', array $data = []);

  /**
   * This method will do POST request to Stackla API.
   *
   * @param string $endpoint
   *   The operation / task for API.
   * @param array $data
   *   The parameter need to be passed.
   *
   * @return \GuzzleHttp\Message\Response
   *   This will return FALSE or json object.
   */
  public function sendPost(string $endpoint = '', array $data = []);

  /**
   * This method will do PUT request to Stackla API.
   *
   * @param string $endpoint
   *   The operation / task for API.
   * @param array $data
   *   The parameter need to be passed.
   *
   * @return \GuzzleHttp\Message\Response
   *   This will return FALSE or json object.
   */
  public function sendPut(string $endpoint = '', array $data = []);

  /**
   * This method will do DELETE request to Stackla API.
   *
   * @param string $endpoint
   *   The operation / task for API.
   * @param array $data
   *   The parameter need to be passed.
   *
   * @return \GuzzleHttp\Message\Response
   *   This will return FALSE or json object.
   */
  public function sendDelete(string $endpoint = '', array $data = []);

  /**
   * This method will return the request HTTP status.
   */
  public function status();

  /**
   * This method will return the request object.
   *
   * @return \GuzzleHttp\Message\Request
   *   The response.
   */
  public function getRequest();

  /**
   * This method will return the response object.
   *
   * @return \GuzzleHttp\Message\Response
   *   The response.
   */
  public function getResponse();

}
