<?php

namespace Drupal\stackla_widget\Api\Validation;

use Drupal\stackla_widget\Api\StacklaModel;

/**
 * The Model Accessor Validator Class.
 *
 * @package Stackla\Validation
 */
class ModelAccessorValidator {

  /**
   * Helper for validating if the class contains methods for a given attribute.
   *
   * @param \Drupal\stackla_widget\Api\StacklaModel $class
   *   An object of StacklaModel.
   * @param string $attributeName
   *   Attribute name.
   *
   * @return bool
   *   The result.
   */
  public static function validate(StacklaModel $class, string $attributeName = '') {
    // Check if $attributeName is string.
    if (gettype($attributeName) !== 'string') {
      return FALSE;
    }
    // If the mode is disabled, bypass the validation.
    foreach (['set' . $attributeName, 'get' . $attributeName] as $methodName) {
      if (get_class($class) == get_class(new StacklaModel())) {
        // Silently return false on cases where you are using StacklaModel.
        return FALSE;
      }
      // Check if both getter and setter exists for given attribute.
      elseif (!method_exists($class, $methodName)) {
        return FALSE;
      }
    }

    return TRUE;
  }

  /**
   * Helper for validating if the class contains property.
   *
   * @param \Drupal\stackla_widget\Api\StacklaModel $class
   *   An object of StacklaModel.
   * @param string $attributeName
   *   The attribute name.
   *
   * @return bool
   *   The result.
   */
  public static function property(StacklaModel $class, string $attributeName = '') {
    // Check if $attributeName is string.
    if (gettype($attributeName) !== 'string') {
      return FALSE;
    }

    $propertyName = $attributeName;
    // If the mode is disabled, bypass the validation.
    if (get_class($class) == get_class(new StacklaModel())) {
      // Silently return false on cases where you are using StacklaModel.
      return FALSE;
    }
    // Check if both getter and setter exists for given attribute.
    elseif (!property_exists($class, $propertyName)) {
      // Delegate the error based on the choice.
      return FALSE;
    }

    return TRUE;
  }

}
