<?php

namespace Drupal\stackla_widget\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Provides a Stackla Widget field type.
 *
 * @FieldType(
 *   id = "stackla_widget",
 *   label = @Translation("Stackla Widget"),
 *   default_widget = "stackla_widget_widget",
 *   default_formatter = "stackla_widget_formatter"
 * )
 */
class StacklaWidgetField extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return [
      'columns' => [
        'wid' => [
          'type' => 'int',
          'not null' => TRUE,
        ],
        'iframe' => [
          'type' => 'blob',
          'not null' => FALSE,
          'size' => 'big',
        ],
      ],
      'indexes' => [
        'wid' => ['wid'],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties = [];
    $properties['wid'] = DataDefinition::create('integer')->setLabel(t('Stackla widget'));
    $properties['iframe'] = DataDefinition::create('string')->setLabel(t('Widget content'));

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $isEmpty =
      empty($this->get('wid')->getValue()) &&
      empty($this->get('iframe')->getValue());

    return $isEmpty;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    return [
      'wid' => '',
    ] + parent::defaultFieldSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    $element = [];
    $options = \Drupal::service('stackla_widget.stackla_service')->getWidgetsOptions();

    $element['wid'] = [
      '#title' => $this->t('Stackla widget'),
      '#type' => 'select',
      '#options' => $options,
      '#default_value' => $this->getSetting('wid'),
    ];

    return $element;
  }

}
