<?php

namespace Drupal\stackla_widget\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\Messenger;
use Drupal\stackla_widget\Service\StacklaService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'stackla_widget_widget' widget.
 *
 * @FieldWidget(
 *   id = "stackla_widget_widget",
 *   module = "stackla_widget",
 *   label = @Translation("Stackla Widget"),
 *   field_types = {
 *     "stackla_widget"
 *   }
 * )
 */
class StacklaWidget extends WidgetBase {


  /**
   * Core messenger.
   *
   * @var \Drupal\Core\Messenger\Messenger
   */
  protected $messenger;

  /**
   * Stackla service.
   *
   * @var \Drupal\stackla_widget\Service\StacklaService
   */
  protected $stackla;

  /**
   * {@inheritdoc}
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, array $third_party_settings, Messenger $messenger, StacklaService $stackla) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $third_party_settings);
    $this->messenger = $messenger;
    $this->stackla = $stackla;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static($plugin_id, $plugin_definition, $configuration['field_definition'], $configuration['settings'], $configuration['third_party_settings'], $container->get('messenger'), $container->get('stackla_widget.stackla_service'));
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $wid = isset($items[$delta]->wid) ? $items[$delta]->wid : '';
    $iframe = isset($items[$delta]->iframe) ? $items[$delta]->iframe : '';
    $options = $this->stackla->getWidgetsOptions();

    $element['wid'] = [
      '#title' => $this->t('Stackla Widget'),
      '#type' => 'select',
      '#options' => $options,
      '#default_value' => $wid,
    ];

    $element['iframe'] = [
      '#type' => 'hidden',
      '#default_value' => isset($iframe) ? $iframe : NULL,
    ];

    $element['#element_validate'] = [
      [$this, 'validate'],
    ];

    return $element;
  }

  /**
   * Form element validation handler for URL alias form element.
   *
   * @param array $element
   *   The form element.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  public function validate(array &$element, FormStateInterface $form_state) {
    $wid = $element['wid']['#value'];
    $iframe = $this->stackla->getIframeById($wid);
    $form_state->setValueForElement($element['iframe'], $iframe);
  }

}
